@@ -1,8 +1,18 @@
+import sys
 from collections import namedtuple
 
 from ua_parser import user_agent_parser
 
 
+PY2 = sys.version_info[0] == 2
+PY3 = sys.version_info[0] == 3
+
+if PY3:
+    string_types = str
+else:
+    string_types = basestring
+
+
 MOBILE_DEVICE_FAMILIES = (
     'iPhone',
     'iPod',
@@ -11,13 +21,15 @@ MOBILE_DEVICE_FAMILIES = (
 )
 
 MOBILE_OS_FAMILIES = (
-    'Windows Phone OS',
+    'Windows Phone',
+    'Windows Phone OS', # Earlier versions of ua-parser returns Windows Phone OS
     'Symbian OS',
 )
 
 TABLET_DEVICE_FAMILIES = (
     'iPad',
-    'Blackberry Playbook',
+    'BlackBerry Playbook',
+    'Blackberry Playbook', # Earlier versions of ua-parser returns "Blackberry" instead of "BlackBerry"
     'Kindle',
     'Kindle Fire',
 )
@@ -25,11 +37,13 @@ TABLET_DEVICE_FAMILIES = (
 TOUCH_CAPABLE_OS_FAMILIES = (
     'iOS',
     'Android',
+    'Windows Phone',
     'Windows Phone OS',
     'Windows RT',
 )
 
 TOUCH_CAPABLE_DEVICE_FAMILIES = (
+    'BlackBerry Playbook',
     'Blackberry Playbook',
     'Kindle Fire',
 )
@@ -37,13 +51,13 @@ TOUCH_CAPABLE_DEVICE_FAMILIES = (
 
 def parse_version(major=None, minor=None, patch=None, patch_minor=None):
     # Returns version number tuple, attributes will be integer if they're numbers
-    if major is not None and isinstance(major, basestring):
+    if major is not None and isinstance(major, string_types):
         major = int(major) if major.isdigit() else major
-    if minor is not None and isinstance(minor, basestring):
+    if minor is not None and isinstance(minor, string_types):
         minor = int(minor) if minor.isdigit() else minor
-    if patch is not None and isinstance(patch, basestring):
+    if patch is not None and isinstance(patch, string_types):
         patch = int(patch) if patch.isdigit() else patch
-    if patch_minor is not None and isinstance(patch_minor, basestring):
+    if patch_minor is not None and isinstance(patch_minor, string_types):
         patch_minor = int(patch_minor) if patch_minor.isdigit() else patch_minor
     if patch_minor:
         return (major, minor, patch, patch_minor)
